cloud

package
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 25, 2023 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddWorkerNodes

func AddWorkerNodes(client *resources.KsctlClient) (int, error)

AddWorkerNodes the user provides the desired no of workerplane not the no of workerplanes to be added

func CreateHACluster

func CreateHACluster(client *resources.KsctlClient) error

func CreateManagedCluster

func CreateManagedCluster(client *resources.KsctlClient) error

func DelWorkerNodes

func DelWorkerNodes(client *resources.KsctlClient) ([]string, error)

DelWorkerNodes uses the noWP as the desired count of workerplane which is desired

func DeleteHACluster

func DeleteHACluster(client *resources.KsctlClient) error

func DeleteManagedCluster

func DeleteManagedCluster(client *resources.KsctlClient) error

func HydrateCloud

func HydrateCloud(client *resources.KsctlClient, operation string, fakeClient bool) error

make it return error

Types

This section is empty.

Jump to