civo

package
v0.0.0-...-ca8a4fa Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 30, 2022 License: Apache-2.0 Imports: 8 Imported by: 1

Documentation

Index

Constants

const (
	RegionLON = "LON1"
	RegionFRA = "FRA1"
	RegionNYC = "NYC1"
)

Variables

This section is empty.

Functions

func ClusterInfoInjecter

func ClusterInfoInjecter(clusterName, reg, size string, noOfNodes int, application, cniPlugin string) payload.CivoProvider

ClusterInfoInjecter Serializes the information which is return as payload.CivoProvider for sending it to API {clustername, regionCode, Size of Nodes, No of nodes, Applications(optional), cniPlugion(optional)}

func CreateCluster

func CreateCluster(cargo payload.CivoProvider) error

CreateCluster creates cluster as provided configuration and returns whether it fails or not

func Credentials

func Credentials() bool

func DeleteCluster

func DeleteCluster(region, name string) error

DeleteCluster deletes cluster from the given name and region

func GetPath

func GetPath(flag int8, params ...string) string

GetPath use this in every function and differentiate the logic by using if-else flag is used to indicate 1 -> KUBECONFIG, 0 -> CREDENTIALS

func SwitchContext

func SwitchContext(clusterName, region string) error

SwitchContext TODO: Add description

Types

This section is empty.

Jump to