Documentation
¶
Index ¶
- func AddWorkerNodes(client *resources.KsctlClient) (int, error)
- func CreateHACluster(client *resources.KsctlClient) error
- func CreateManagedCluster(client *resources.KsctlClient) error
- func DelWorkerNodes(client *resources.KsctlClient) ([]string, error)
- func DeleteHACluster(client *resources.KsctlClient) error
- func DeleteManagedCluster(client *resources.KsctlClient) error
- func HydrateCloud(client *resources.KsctlClient, operation string, fakeClient bool) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddWorkerNodes ¶
func AddWorkerNodes(client *resources.KsctlClient) (int, error)
AddWorkerNodes the user provides the desired no of workerplane not the no of workerplanes to be added
func CreateHACluster ¶
func CreateHACluster(client *resources.KsctlClient) error
func CreateManagedCluster ¶
func CreateManagedCluster(client *resources.KsctlClient) error
func DelWorkerNodes ¶
func DelWorkerNodes(client *resources.KsctlClient) ([]string, error)
DelWorkerNodes uses the noWP as the desired count of workerplane which is desired
func DeleteHACluster ¶
func DeleteHACluster(client *resources.KsctlClient) error
func DeleteManagedCluster ¶
func DeleteManagedCluster(client *resources.KsctlClient) error
func HydrateCloud ¶
func HydrateCloud(client *resources.KsctlClient, operation string, fakeClient bool) error
make it return error
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.