Documentation
¶
Index ¶
- Constants
- func GetInputCredential(storage resources.StorageFactory) error
- func GetRAWClusterInfos(storage resources.StorageFactory) ([]cloud_control_res.AllClusterData, error)
- type AzureGo
- type AzureGoClient
- func (azclient *AzureGoClient) BeginCreateAKS(resourceName string, parameters armcontainerservice.ManagedCluster, ...) (...)
- func (azclient *AzureGoClient) BeginCreateNIC(networkInterfaceName string, parameters armnetwork.Interface, ...) (*runtime.Poller[armnetwork.InterfacesClientCreateOrUpdateResponse], error)
- func (azclient *AzureGoClient) BeginCreatePubIP(publicIPAddressName string, parameters armnetwork.PublicIPAddress, ...) (*runtime.Poller[armnetwork.PublicIPAddressesClientCreateOrUpdateResponse], ...)
- func (azclient *AzureGoClient) BeginCreateSecurityGrp(networkSecurityGroupName string, parameters armnetwork.SecurityGroup, ...) (*runtime.Poller[armnetwork.SecurityGroupsClientCreateOrUpdateResponse], error)
- func (azclient *AzureGoClient) BeginCreateSubNet(virtualNetworkName string, subnetName string, ...) (*runtime.Poller[armnetwork.SubnetsClientCreateOrUpdateResponse], error)
- func (azclient *AzureGoClient) BeginCreateVM(vmName string, parameters armcompute.VirtualMachine, ...) (*runtime.Poller[armcompute.VirtualMachinesClientCreateOrUpdateResponse], error)
- func (azclient *AzureGoClient) BeginCreateVirtNet(virtualNetworkName string, parameters armnetwork.VirtualNetwork, ...) (*runtime.Poller[armnetwork.VirtualNetworksClientCreateOrUpdateResponse], error)
- func (azclient *AzureGoClient) BeginDeleteAKS(resourceName string, ...) (*runtime.Poller[armcontainerservice.ManagedClustersClientDeleteResponse], ...)
- func (azclient *AzureGoClient) BeginDeleteDisk(diskName string, options *armcompute.DisksClientBeginDeleteOptions) (*runtime.Poller[armcompute.DisksClientDeleteResponse], error)
- func (azclient *AzureGoClient) BeginDeleteNIC(networkInterfaceName string, ...) (*runtime.Poller[armnetwork.InterfacesClientDeleteResponse], error)
- func (azclient *AzureGoClient) BeginDeletePubIP(publicIPAddressName string, ...) (*runtime.Poller[armnetwork.PublicIPAddressesClientDeleteResponse], error)
- func (azclient *AzureGoClient) BeginDeleteResourceGrp(options *armresources.ResourceGroupsClientBeginDeleteOptions) (*runtime.Poller[armresources.ResourceGroupsClientDeleteResponse], error)
- func (azclient *AzureGoClient) BeginDeleteSecurityGrp(networkSecurityGroupName string, ...) (*runtime.Poller[armnetwork.SecurityGroupsClientDeleteResponse], error)
- func (azclient *AzureGoClient) BeginDeleteSubNet(virtualNetworkName string, subnetName string, ...) (*runtime.Poller[armnetwork.SubnetsClientDeleteResponse], error)
- func (azclient *AzureGoClient) BeginDeleteVM(vmName string, options *armcompute.VirtualMachinesClientBeginDeleteOptions) (*runtime.Poller[armcompute.VirtualMachinesClientDeleteResponse], error)
- func (azclient *AzureGoClient) BeginDeleteVirtNet(virtualNetworkName string, ...) (*runtime.Poller[armnetwork.VirtualNetworksClientDeleteResponse], error)
- func (azclient *AzureGoClient) CreateResourceGrp(parameters armresources.ResourceGroup, ...) (armresources.ResourceGroupsClientCreateOrUpdateResponse, error)
- func (azclient *AzureGoClient) CreateSSHKey(sshPublicKeyName string, parameters armcompute.SSHPublicKeyResource, ...) (armcompute.SSHPublicKeysClientCreateResponse, error)
- func (azclient *AzureGoClient) DeleteSSHKey(sshPublicKeyName string, options *armcompute.SSHPublicKeysClientDeleteOptions) (armcompute.SSHPublicKeysClientDeleteResponse, error)
- func (azclient *AzureGoClient) InitClient(storage resources.StorageFactory) error
- func (azclient *AzureGoClient) ListClusterAdminCredentials(resourceName string, ...) (armcontainerservice.ManagedClustersClientListClusterAdminCredentialsResponse, ...)
- func (azclient *AzureGoClient) ListKubernetesVersions() (armcontainerservicev4.ManagedClustersClientListKubernetesVersionsResponse, ...)
- func (azclient *AzureGoClient) ListLocations() ([]string, error)
- func (azclient *AzureGoClient) ListVMTypes() ([]string, error)
- func (obj *AzureGoClient) PollUntilDoneCreateAKS(ctx context.Context, ...) (armcontainerservice.ManagedClustersClientCreateOrUpdateResponse, error)
- func (obj *AzureGoClient) PollUntilDoneCreateNSG(ctx context.Context, ...) (armnetwork.SecurityGroupsClientCreateOrUpdateResponse, error)
- func (*AzureGoClient) PollUntilDoneCreateNetInterface(ctx context.Context, ...) (armnetwork.InterfacesClientCreateOrUpdateResponse, error)
- func (*AzureGoClient) PollUntilDoneCreatePubIP(ctx context.Context, ...) (armnetwork.PublicIPAddressesClientCreateOrUpdateResponse, error)
- func (obj *AzureGoClient) PollUntilDoneCreateSubNet(ctx context.Context, ...) (armnetwork.SubnetsClientCreateOrUpdateResponse, error)
- func (*AzureGoClient) PollUntilDoneCreateVM(ctx context.Context, ...) (armcompute.VirtualMachinesClientCreateOrUpdateResponse, error)
- func (obj *AzureGoClient) PollUntilDoneCreateVirtNet(ctx context.Context, ...) (armnetwork.VirtualNetworksClientCreateOrUpdateResponse, error)
- func (obj *AzureGoClient) PollUntilDoneDelAKS(ctx context.Context, ...) (armcontainerservice.ManagedClustersClientDeleteResponse, error)
- func (*AzureGoClient) PollUntilDoneDelDisk(ctx context.Context, ...) (armcompute.DisksClientDeleteResponse, error)
- func (obj *AzureGoClient) PollUntilDoneDelNSG(ctx context.Context, ...) (armnetwork.SecurityGroupsClientDeleteResponse, error)
- func (*AzureGoClient) PollUntilDoneDelNetInterface(ctx context.Context, ...) (armnetwork.InterfacesClientDeleteResponse, error)
- func (*AzureGoClient) PollUntilDoneDelPubIP(ctx context.Context, ...) (armnetwork.PublicIPAddressesClientDeleteResponse, error)
- func (obj *AzureGoClient) PollUntilDoneDelResourceGrp(ctx context.Context, ...) (armresources.ResourceGroupsClientDeleteResponse, error)
- func (obj *AzureGoClient) PollUntilDoneDelSubNet(ctx context.Context, ...) (armnetwork.SubnetsClientDeleteResponse, error)
- func (*AzureGoClient) PollUntilDoneDelVM(ctx context.Context, ...) (armcompute.VirtualMachinesClientDeleteResponse, error)
- func (obj *AzureGoClient) PollUntilDoneDelVirtNet(ctx context.Context, ...) (armnetwork.VirtualNetworksClientDeleteResponse, error)
- func (azclient *AzureGoClient) PublicIPClient() (*armnetwork.PublicIPAddressesClient, error)
- func (azclient *AzureGoClient) SetRegion(reg string)
- func (azclient *AzureGoClient) SetResourceGrp(grp string)
- type AzureGoMockClient
- func (mock *AzureGoMockClient) BeginCreateAKS(resourceName string, parameters armcontainerservice.ManagedCluster, ...) (...)
- func (mock *AzureGoMockClient) BeginCreateNIC(networkInterfaceName string, parameters armnetwork.Interface, ...) (*runtime.Poller[armnetwork.InterfacesClientCreateOrUpdateResponse], error)
- func (mock *AzureGoMockClient) BeginCreatePubIP(publicIPAddressName string, parameters armnetwork.PublicIPAddress, ...) (*runtime.Poller[armnetwork.PublicIPAddressesClientCreateOrUpdateResponse], ...)
- func (mock *AzureGoMockClient) BeginCreateSecurityGrp(networkSecurityGroupName string, parameters armnetwork.SecurityGroup, ...) (*runtime.Poller[armnetwork.SecurityGroupsClientCreateOrUpdateResponse], error)
- func (mock *AzureGoMockClient) BeginCreateSubNet(virtualNetworkName string, subnetName string, ...) (*runtime.Poller[armnetwork.SubnetsClientCreateOrUpdateResponse], error)
- func (mock *AzureGoMockClient) BeginCreateVM(vmName string, parameters armcompute.VirtualMachine, ...) (*runtime.Poller[armcompute.VirtualMachinesClientCreateOrUpdateResponse], error)
- func (mock *AzureGoMockClient) BeginCreateVirtNet(virtualNetworkName string, parameters armnetwork.VirtualNetwork, ...) (*runtime.Poller[armnetwork.VirtualNetworksClientCreateOrUpdateResponse], error)
- func (mock *AzureGoMockClient) BeginDeleteAKS(resourceName string, ...) (*runtime.Poller[armcontainerservice.ManagedClustersClientDeleteResponse], ...)
- func (mock *AzureGoMockClient) BeginDeleteDisk(diskName string, options *armcompute.DisksClientBeginDeleteOptions) (*runtime.Poller[armcompute.DisksClientDeleteResponse], error)
- func (mock *AzureGoMockClient) BeginDeleteNIC(networkInterfaceName string, ...) (*runtime.Poller[armnetwork.InterfacesClientDeleteResponse], error)
- func (mock *AzureGoMockClient) BeginDeletePubIP(publicIPAddressName string, ...) (*runtime.Poller[armnetwork.PublicIPAddressesClientDeleteResponse], error)
- func (mock *AzureGoMockClient) BeginDeleteResourceGrp(options *armresources.ResourceGroupsClientBeginDeleteOptions) (*runtime.Poller[armresources.ResourceGroupsClientDeleteResponse], error)
- func (mock *AzureGoMockClient) BeginDeleteSecurityGrp(networkSecurityGroupName string, ...) (*runtime.Poller[armnetwork.SecurityGroupsClientDeleteResponse], error)
- func (mock *AzureGoMockClient) BeginDeleteSubNet(virtualNetworkName string, subnetName string, ...) (*runtime.Poller[armnetwork.SubnetsClientDeleteResponse], error)
- func (mock *AzureGoMockClient) BeginDeleteVM(vmName string, options *armcompute.VirtualMachinesClientBeginDeleteOptions) (*runtime.Poller[armcompute.VirtualMachinesClientDeleteResponse], error)
- func (mock *AzureGoMockClient) BeginDeleteVirtNet(virtualNetworkName string, ...) (*runtime.Poller[armnetwork.VirtualNetworksClientDeleteResponse], error)
- func (mock *AzureGoMockClient) CreateResourceGrp(parameters armresources.ResourceGroup, ...) (armresources.ResourceGroupsClientCreateOrUpdateResponse, error)
- func (mock *AzureGoMockClient) CreateSSHKey(sshPublicKeyName string, parameters armcompute.SSHPublicKeyResource, ...) (armcompute.SSHPublicKeysClientCreateResponse, error)
- func (mock *AzureGoMockClient) DeleteSSHKey(sshPublicKeyName string, options *armcompute.SSHPublicKeysClientDeleteOptions) (armcompute.SSHPublicKeysClientDeleteResponse, error)
- func (mock *AzureGoMockClient) InitClient(storage resources.StorageFactory) error
- func (mock *AzureGoMockClient) ListClusterAdminCredentials(resourceName string, ...) (armcontainerservice.ManagedClustersClientListClusterAdminCredentialsResponse, ...)
- func (mock *AzureGoMockClient) ListKubernetesVersions() (armcontainerservicev4.ManagedClustersClientListKubernetesVersionsResponse, ...)
- func (mock *AzureGoMockClient) ListLocations() ([]string, error)
- func (mock *AzureGoMockClient) ListVMTypes() ([]string, error)
- func (mock *AzureGoMockClient) PollUntilDoneCreateAKS(ctx context.Context, ...) (armcontainerservice.ManagedClustersClientCreateOrUpdateResponse, error)
- func (mock *AzureGoMockClient) PollUntilDoneCreateNSG(ctx context.Context, ...) (armnetwork.SecurityGroupsClientCreateOrUpdateResponse, error)
- func (mock *AzureGoMockClient) PollUntilDoneCreateNetInterface(ctx context.Context, ...) (armnetwork.InterfacesClientCreateOrUpdateResponse, error)
- func (mock *AzureGoMockClient) PollUntilDoneCreatePubIP(ctx context.Context, ...) (armnetwork.PublicIPAddressesClientCreateOrUpdateResponse, error)
- func (mock *AzureGoMockClient) PollUntilDoneCreateSubNet(ctx context.Context, ...) (armnetwork.SubnetsClientCreateOrUpdateResponse, error)
- func (mock *AzureGoMockClient) PollUntilDoneCreateVM(ctx context.Context, ...) (armcompute.VirtualMachinesClientCreateOrUpdateResponse, error)
- func (mock *AzureGoMockClient) PollUntilDoneCreateVirtNet(ctx context.Context, ...) (armnetwork.VirtualNetworksClientCreateOrUpdateResponse, error)
- func (mock *AzureGoMockClient) PollUntilDoneDelAKS(ctx context.Context, ...) (armcontainerservice.ManagedClustersClientDeleteResponse, error)
- func (mock *AzureGoMockClient) PollUntilDoneDelDisk(ctx context.Context, ...) (armcompute.DisksClientDeleteResponse, error)
- func (mock *AzureGoMockClient) PollUntilDoneDelNSG(ctx context.Context, ...) (armnetwork.SecurityGroupsClientDeleteResponse, error)
- func (mock *AzureGoMockClient) PollUntilDoneDelNetInterface(ctx context.Context, ...) (armnetwork.InterfacesClientDeleteResponse, error)
- func (mock *AzureGoMockClient) PollUntilDoneDelPubIP(ctx context.Context, ...) (armnetwork.PublicIPAddressesClientDeleteResponse, error)
- func (mock *AzureGoMockClient) PollUntilDoneDelResourceGrp(ctx context.Context, ...) (armresources.ResourceGroupsClientDeleteResponse, error)
- func (mock *AzureGoMockClient) PollUntilDoneDelSubNet(ctx context.Context, ...) (armnetwork.SubnetsClientDeleteResponse, error)
- func (mock *AzureGoMockClient) PollUntilDoneDelVM(ctx context.Context, ...) (armcompute.VirtualMachinesClientDeleteResponse, error)
- func (mock *AzureGoMockClient) PollUntilDoneDelVirtNet(ctx context.Context, ...) (armnetwork.VirtualNetworksClientDeleteResponse, error)
- func (mock *AzureGoMockClient) SetRegion(s string)
- func (mock *AzureGoMockClient) SetResourceGrp(s string)
- type AzureProvider
- func (cloud *AzureProvider) Application(s string) resources.CloudFactory
- func (cloud *AzureProvider) CNI(s string) resources.CloudFactory
- func (obj *AzureProvider) CreateNetworkInterface(ctx context.Context, storage resources.StorageFactory, nicName string, ...) error
- func (obj *AzureProvider) CreatePublicIP(ctx context.Context, storage resources.StorageFactory, publicIPName string, ...) error
- func (obj *AzureProvider) CreateSubnet(ctx context.Context, storage resources.StorageFactory, subnetName string) error
- func (obj *AzureProvider) CreateUploadSSHKeyPair(storage resources.StorageFactory) error
- func (obj *AzureProvider) CreateVirtualNetwork(ctx context.Context, storage resources.StorageFactory, resName string) error
- func (obj *AzureProvider) DelFirewall(storage resources.StorageFactory) error
- func (obj *AzureProvider) DelManagedCluster(storage resources.StorageFactory) error
- func (obj *AzureProvider) DelNetwork(storage resources.StorageFactory) error
- func (obj *AzureProvider) DelSSHKeyPair(storage resources.StorageFactory) error
- func (obj *AzureProvider) DelVM(storage resources.StorageFactory, indexNo int) error
- func (obj *AzureProvider) DeleteDisk(ctx context.Context, storage resources.StorageFactory, index int) error
- func (obj *AzureProvider) DeleteNetworkInterface(ctx context.Context, storage resources.StorageFactory, index int) error
- func (obj *AzureProvider) DeletePublicIP(ctx context.Context, storage resources.StorageFactory, index int) error
- func (obj *AzureProvider) DeleteSubnet(ctx context.Context, storage resources.StorageFactory) error
- func (obj *AzureProvider) DeleteVirtualNetwork(ctx context.Context, storage resources.StorageFactory) error
- func (*AzureProvider) GetHostNameAllWorkerNode() []string
- func (*AzureProvider) GetManagedKubernetes(resources.StorageFactory)
- func (*AzureProvider) GetStateForHACluster(storage resources.StorageFactory) (cloud_control_res.CloudResourceState, error)
- func (obj *AzureProvider) InitState(storage resources.StorageFactory, operation string) error
- func (cloud *AzureProvider) Name(resName string) resources.CloudFactory
- func (obj *AzureProvider) NewFirewall(storage resources.StorageFactory) error
- func (obj *AzureProvider) NewManagedCluster(storage resources.StorageFactory, noOfNodes int) error
- func (obj *AzureProvider) NewNetwork(storage resources.StorageFactory) error
- func (obj *AzureProvider) NewVM(storage resources.StorageFactory, indexNo int) error
- func (obj *AzureProvider) NoOfControlPlane(no int, setter bool) (int, error)
- func (obj *AzureProvider) NoOfDataStore(no int, setter bool) (int, error)
- func (obj *AzureProvider) NoOfWorkerPlane(storage resources.StorageFactory, no int, setter bool) (int, error)
- func (cloud *AzureProvider) Role(resRole string) resources.CloudFactory
- func (cloud *AzureProvider) SupportForApplications() bool
- func (cloud *AzureProvider) SupportForCNI() bool
- func (obj *AzureProvider) SwitchCluster(storage resources.StorageFactory) error
- func (cloud *AzureProvider) VMType(size string) resources.CloudFactory
- func (obj *AzureProvider) Version(ver string) resources.CloudFactory
- func (cloud *AzureProvider) Visibility(toBePublic bool) resources.CloudFactory
- type AzureStateVM
- type AzureStateVMs
- type Credential
- type Metadata
- type StateConfiguration
Constants ¶
Variables ¶
This section is empty.
Functions ¶
func GetInputCredential ¶
func GetInputCredential(storage resources.StorageFactory) error
func GetRAWClusterInfos ¶
func GetRAWClusterInfos(storage resources.StorageFactory) ([]cloud_control_res.AllClusterData, error)
Types ¶
type AzureGo ¶
type AzureGo interface {
InitClient(storage resources.StorageFactory) error
SetRegion(string)
SetResourceGrp(string)
ListLocations() ([]string, error)
ListKubernetesVersions() (armcontainerservicev4.ManagedClustersClientListKubernetesVersionsResponse, error)
ListVMTypes() ([]string, error)
CreateResourceGrp(parameters armresources.ResourceGroup,
options *armresources.ResourceGroupsClientCreateOrUpdateOptions) (armresources.ResourceGroupsClientCreateOrUpdateResponse, error)
BeginDeleteResourceGrp(
options *armresources.ResourceGroupsClientBeginDeleteOptions) (*runtime.Poller[armresources.ResourceGroupsClientDeleteResponse], error)
BeginCreateVirtNet(virtualNetworkName string, parameters armnetwork.VirtualNetwork,
options *armnetwork.VirtualNetworksClientBeginCreateOrUpdateOptions) (*runtime.Poller[armnetwork.VirtualNetworksClientCreateOrUpdateResponse], error)
BeginDeleteVirtNet(virtualNetworkName string,
options *armnetwork.VirtualNetworksClientBeginDeleteOptions) (*runtime.Poller[armnetwork.VirtualNetworksClientDeleteResponse], error)
BeginCreateSubNet(virtualNetworkName string, subnetName string, subnetParameters armnetwork.Subnet,
options *armnetwork.SubnetsClientBeginCreateOrUpdateOptions) (*runtime.Poller[armnetwork.SubnetsClientCreateOrUpdateResponse], error)
BeginDeleteSubNet(virtualNetworkName string, subnetName string,
options *armnetwork.SubnetsClientBeginDeleteOptions) (*runtime.Poller[armnetwork.SubnetsClientDeleteResponse], error)
BeginDeleteSecurityGrp(networkSecurityGroupName string,
options *armnetwork.SecurityGroupsClientBeginDeleteOptions) (*runtime.Poller[armnetwork.SecurityGroupsClientDeleteResponse], error)
BeginCreateSecurityGrp(networkSecurityGroupName string, parameters armnetwork.SecurityGroup,
options *armnetwork.SecurityGroupsClientBeginCreateOrUpdateOptions) (*runtime.Poller[armnetwork.SecurityGroupsClientCreateOrUpdateResponse], error)
CreateSSHKey(sshPublicKeyName string, parameters armcompute.SSHPublicKeyResource,
options *armcompute.SSHPublicKeysClientCreateOptions) (armcompute.SSHPublicKeysClientCreateResponse, error)
DeleteSSHKey(sshPublicKeyName string,
options *armcompute.SSHPublicKeysClientDeleteOptions) (armcompute.SSHPublicKeysClientDeleteResponse, error)
BeginCreateVM(vmName string, parameters armcompute.VirtualMachine,
options *armcompute.VirtualMachinesClientBeginCreateOrUpdateOptions) (*runtime.Poller[armcompute.VirtualMachinesClientCreateOrUpdateResponse], error)
BeginDeleteVM(vmName string,
options *armcompute.VirtualMachinesClientBeginDeleteOptions) (*runtime.Poller[armcompute.VirtualMachinesClientDeleteResponse], error)
BeginDeleteDisk(diskName string,
options *armcompute.DisksClientBeginDeleteOptions) (*runtime.Poller[armcompute.DisksClientDeleteResponse], error)
BeginCreatePubIP(publicIPAddressName string, parameters armnetwork.PublicIPAddress,
options *armnetwork.PublicIPAddressesClientBeginCreateOrUpdateOptions) (*runtime.Poller[armnetwork.PublicIPAddressesClientCreateOrUpdateResponse], error)
BeginDeletePubIP(publicIPAddressName string,
options *armnetwork.PublicIPAddressesClientBeginDeleteOptions) (*runtime.Poller[armnetwork.PublicIPAddressesClientDeleteResponse], error)
BeginCreateNIC(networkInterfaceName string, parameters armnetwork.Interface,
options *armnetwork.InterfacesClientBeginCreateOrUpdateOptions) (*runtime.Poller[armnetwork.InterfacesClientCreateOrUpdateResponse], error)
BeginDeleteNIC(networkInterfaceName string,
options *armnetwork.InterfacesClientBeginDeleteOptions) (*runtime.Poller[armnetwork.InterfacesClientDeleteResponse], error)
BeginDeleteAKS(resourceName string,
options *armcontainerservice.ManagedClustersClientBeginDeleteOptions) (*runtime.Poller[armcontainerservice.ManagedClustersClientDeleteResponse], error)
BeginCreateAKS(resourceName string, parameters armcontainerservice.ManagedCluster,
options *armcontainerservice.ManagedClustersClientBeginCreateOrUpdateOptions) (*runtime.Poller[armcontainerservice.ManagedClustersClientCreateOrUpdateResponse], error)
ListClusterAdminCredentials(resourceName string,
options *armcontainerservice.ManagedClustersClientListClusterAdminCredentialsOptions) (armcontainerservice.ManagedClustersClientListClusterAdminCredentialsResponse, error)
PollUntilDoneDelNSG(ctx context.Context, poll *runtime.Poller[armnetwork.SecurityGroupsClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armnetwork.SecurityGroupsClientDeleteResponse, error)
PollUntilDoneCreateNSG(ctx context.Context, poll *runtime.Poller[armnetwork.SecurityGroupsClientCreateOrUpdateResponse], options *runtime.PollUntilDoneOptions) (armnetwork.SecurityGroupsClientCreateOrUpdateResponse, error)
PollUntilDoneDelResourceGrp(ctx context.Context, poll *runtime.Poller[armresources.ResourceGroupsClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armresources.ResourceGroupsClientDeleteResponse, error)
PollUntilDoneCreateSubNet(ctx context.Context, poll *runtime.Poller[armnetwork.SubnetsClientCreateOrUpdateResponse], options *runtime.PollUntilDoneOptions) (armnetwork.SubnetsClientCreateOrUpdateResponse, error)
PollUntilDoneDelSubNet(ctx context.Context, poll *runtime.Poller[armnetwork.SubnetsClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armnetwork.SubnetsClientDeleteResponse, error)
PollUntilDoneCreateVirtNet(ctx context.Context, poll *runtime.Poller[armnetwork.VirtualNetworksClientCreateOrUpdateResponse], options *runtime.PollUntilDoneOptions) (armnetwork.VirtualNetworksClientCreateOrUpdateResponse, error)
PollUntilDoneDelVirtNet(ctx context.Context, poll *runtime.Poller[armnetwork.VirtualNetworksClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armnetwork.VirtualNetworksClientDeleteResponse, error)
PollUntilDoneCreateAKS(ctx context.Context, poll *runtime.Poller[armcontainerservice.ManagedClustersClientCreateOrUpdateResponse], options *runtime.PollUntilDoneOptions) (armcontainerservice.ManagedClustersClientCreateOrUpdateResponse, error)
PollUntilDoneDelAKS(ctx context.Context, poll *runtime.Poller[armcontainerservice.ManagedClustersClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armcontainerservice.ManagedClustersClientDeleteResponse, error)
PollUntilDoneDelVM(ctx context.Context, poll *runtime.Poller[armcompute.VirtualMachinesClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armcompute.VirtualMachinesClientDeleteResponse, error)
PollUntilDoneCreateVM(ctx context.Context, poll *runtime.Poller[armcompute.VirtualMachinesClientCreateOrUpdateResponse], options *runtime.PollUntilDoneOptions) (armcompute.VirtualMachinesClientCreateOrUpdateResponse, error)
PollUntilDoneDelDisk(ctx context.Context, poll *runtime.Poller[armcompute.DisksClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armcompute.DisksClientDeleteResponse, error)
PollUntilDoneCreatePubIP(ctx context.Context, poll *runtime.Poller[armnetwork.PublicIPAddressesClientCreateOrUpdateResponse], options *runtime.PollUntilDoneOptions) (armnetwork.PublicIPAddressesClientCreateOrUpdateResponse, error)
PollUntilDoneDelPubIP(ctx context.Context, poll *runtime.Poller[armnetwork.PublicIPAddressesClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armnetwork.PublicIPAddressesClientDeleteResponse, error)
PollUntilDoneCreateNetInterface(ctx context.Context, poll *runtime.Poller[armnetwork.InterfacesClientCreateOrUpdateResponse], options *runtime.PollUntilDoneOptions) (armnetwork.InterfacesClientCreateOrUpdateResponse, error)
PollUntilDoneDelNetInterface(ctx context.Context, poll *runtime.Poller[armnetwork.InterfacesClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armnetwork.InterfacesClientDeleteResponse, error)
}
func ProvideClient ¶
func ProvideClient() AzureGo
func ProvideMockClient ¶
func ProvideMockClient() AzureGo
type AzureGoClient ¶
type AzureGoClient struct {
SubscriptionID string
AzureTokenCred azcore.TokenCredential
Region string
ResourceGrp string
}
func (*AzureGoClient) BeginCreateAKS ¶
func (azclient *AzureGoClient) BeginCreateAKS(resourceName string, parameters armcontainerservice.ManagedCluster, options *armcontainerservice.ManagedClustersClientBeginCreateOrUpdateOptions) (*runtime.Poller[armcontainerservice.ManagedClustersClientCreateOrUpdateResponse], error)
func (*AzureGoClient) BeginCreateNIC ¶
func (azclient *AzureGoClient) BeginCreateNIC(networkInterfaceName string, parameters armnetwork.Interface, options *armnetwork.InterfacesClientBeginCreateOrUpdateOptions) (*runtime.Poller[armnetwork.InterfacesClientCreateOrUpdateResponse], error)
func (*AzureGoClient) BeginCreatePubIP ¶
func (azclient *AzureGoClient) BeginCreatePubIP(publicIPAddressName string, parameters armnetwork.PublicIPAddress, options *armnetwork.PublicIPAddressesClientBeginCreateOrUpdateOptions) (*runtime.Poller[armnetwork.PublicIPAddressesClientCreateOrUpdateResponse], error)
func (*AzureGoClient) BeginCreateSecurityGrp ¶
func (azclient *AzureGoClient) BeginCreateSecurityGrp(networkSecurityGroupName string, parameters armnetwork.SecurityGroup, options *armnetwork.SecurityGroupsClientBeginCreateOrUpdateOptions) (*runtime.Poller[armnetwork.SecurityGroupsClientCreateOrUpdateResponse], error)
func (*AzureGoClient) BeginCreateSubNet ¶
func (azclient *AzureGoClient) BeginCreateSubNet(virtualNetworkName string, subnetName string, subnetParameters armnetwork.Subnet, options *armnetwork.SubnetsClientBeginCreateOrUpdateOptions) (*runtime.Poller[armnetwork.SubnetsClientCreateOrUpdateResponse], error)
func (*AzureGoClient) BeginCreateVM ¶
func (azclient *AzureGoClient) BeginCreateVM(vmName string, parameters armcompute.VirtualMachine, options *armcompute.VirtualMachinesClientBeginCreateOrUpdateOptions) (*runtime.Poller[armcompute.VirtualMachinesClientCreateOrUpdateResponse], error)
func (*AzureGoClient) BeginCreateVirtNet ¶
func (azclient *AzureGoClient) BeginCreateVirtNet(virtualNetworkName string, parameters armnetwork.VirtualNetwork, options *armnetwork.VirtualNetworksClientBeginCreateOrUpdateOptions) (*runtime.Poller[armnetwork.VirtualNetworksClientCreateOrUpdateResponse], error)
func (*AzureGoClient) BeginDeleteAKS ¶
func (azclient *AzureGoClient) BeginDeleteAKS(resourceName string, options *armcontainerservice.ManagedClustersClientBeginDeleteOptions) (*runtime.Poller[armcontainerservice.ManagedClustersClientDeleteResponse], error)
func (*AzureGoClient) BeginDeleteDisk ¶
func (azclient *AzureGoClient) BeginDeleteDisk(diskName string, options *armcompute.DisksClientBeginDeleteOptions) (*runtime.Poller[armcompute.DisksClientDeleteResponse], error)
func (*AzureGoClient) BeginDeleteNIC ¶
func (azclient *AzureGoClient) BeginDeleteNIC(networkInterfaceName string, options *armnetwork.InterfacesClientBeginDeleteOptions) (*runtime.Poller[armnetwork.InterfacesClientDeleteResponse], error)
func (*AzureGoClient) BeginDeletePubIP ¶
func (azclient *AzureGoClient) BeginDeletePubIP(publicIPAddressName string, options *armnetwork.PublicIPAddressesClientBeginDeleteOptions) (*runtime.Poller[armnetwork.PublicIPAddressesClientDeleteResponse], error)
func (*AzureGoClient) BeginDeleteResourceGrp ¶
func (azclient *AzureGoClient) BeginDeleteResourceGrp(options *armresources.ResourceGroupsClientBeginDeleteOptions) (*runtime.Poller[armresources.ResourceGroupsClientDeleteResponse], error)
func (*AzureGoClient) BeginDeleteSecurityGrp ¶
func (azclient *AzureGoClient) BeginDeleteSecurityGrp(networkSecurityGroupName string, options *armnetwork.SecurityGroupsClientBeginDeleteOptions) (*runtime.Poller[armnetwork.SecurityGroupsClientDeleteResponse], error)
func (*AzureGoClient) BeginDeleteSubNet ¶
func (azclient *AzureGoClient) BeginDeleteSubNet(virtualNetworkName string, subnetName string, options *armnetwork.SubnetsClientBeginDeleteOptions) (*runtime.Poller[armnetwork.SubnetsClientDeleteResponse], error)
func (*AzureGoClient) BeginDeleteVM ¶
func (azclient *AzureGoClient) BeginDeleteVM(vmName string, options *armcompute.VirtualMachinesClientBeginDeleteOptions) (*runtime.Poller[armcompute.VirtualMachinesClientDeleteResponse], error)
func (*AzureGoClient) BeginDeleteVirtNet ¶
func (azclient *AzureGoClient) BeginDeleteVirtNet(virtualNetworkName string, options *armnetwork.VirtualNetworksClientBeginDeleteOptions) (*runtime.Poller[armnetwork.VirtualNetworksClientDeleteResponse], error)
func (*AzureGoClient) CreateResourceGrp ¶
func (azclient *AzureGoClient) CreateResourceGrp(parameters armresources.ResourceGroup, options *armresources.ResourceGroupsClientCreateOrUpdateOptions) (armresources.ResourceGroupsClientCreateOrUpdateResponse, error)
func (*AzureGoClient) CreateSSHKey ¶
func (azclient *AzureGoClient) CreateSSHKey(sshPublicKeyName string, parameters armcompute.SSHPublicKeyResource, options *armcompute.SSHPublicKeysClientCreateOptions) (armcompute.SSHPublicKeysClientCreateResponse, error)
func (*AzureGoClient) DeleteSSHKey ¶
func (azclient *AzureGoClient) DeleteSSHKey(sshPublicKeyName string, options *armcompute.SSHPublicKeysClientDeleteOptions) (armcompute.SSHPublicKeysClientDeleteResponse, error)
func (*AzureGoClient) InitClient ¶
func (azclient *AzureGoClient) InitClient(storage resources.StorageFactory) error
func (*AzureGoClient) ListClusterAdminCredentials ¶
func (azclient *AzureGoClient) ListClusterAdminCredentials(resourceName string, options *armcontainerservice.ManagedClustersClientListClusterAdminCredentialsOptions) (armcontainerservice.ManagedClustersClientListClusterAdminCredentialsResponse, error)
func (*AzureGoClient) ListKubernetesVersions ¶
func (azclient *AzureGoClient) ListKubernetesVersions() (armcontainerservicev4.ManagedClustersClientListKubernetesVersionsResponse, error)
func (*AzureGoClient) ListLocations ¶
func (azclient *AzureGoClient) ListLocations() ([]string, error)
func (*AzureGoClient) ListVMTypes ¶
func (azclient *AzureGoClient) ListVMTypes() ([]string, error)
func (*AzureGoClient) PollUntilDoneCreateAKS ¶
func (obj *AzureGoClient) PollUntilDoneCreateAKS(ctx context.Context, poll *runtime.Poller[armcontainerservice.ManagedClustersClientCreateOrUpdateResponse], options *runtime.PollUntilDoneOptions) (armcontainerservice.ManagedClustersClientCreateOrUpdateResponse, error)
func (*AzureGoClient) PollUntilDoneCreateNSG ¶
func (obj *AzureGoClient) PollUntilDoneCreateNSG(ctx context.Context, poll *runtime.Poller[armnetwork.SecurityGroupsClientCreateOrUpdateResponse], options *runtime.PollUntilDoneOptions) (armnetwork.SecurityGroupsClientCreateOrUpdateResponse, error)
func (*AzureGoClient) PollUntilDoneCreateNetInterface ¶
func (*AzureGoClient) PollUntilDoneCreateNetInterface(ctx context.Context, poll *runtime.Poller[armnetwork.InterfacesClientCreateOrUpdateResponse], options *runtime.PollUntilDoneOptions) (armnetwork.InterfacesClientCreateOrUpdateResponse, error)
PollUntilDoneCreateNetInterface implements AzureGo.
func (*AzureGoClient) PollUntilDoneCreatePubIP ¶
func (*AzureGoClient) PollUntilDoneCreatePubIP(ctx context.Context, poll *runtime.Poller[armnetwork.PublicIPAddressesClientCreateOrUpdateResponse], options *runtime.PollUntilDoneOptions) (armnetwork.PublicIPAddressesClientCreateOrUpdateResponse, error)
PollUntilDoneCreatePubIP implements AzureGo.
func (*AzureGoClient) PollUntilDoneCreateSubNet ¶
func (obj *AzureGoClient) PollUntilDoneCreateSubNet(ctx context.Context, poll *runtime.Poller[armnetwork.SubnetsClientCreateOrUpdateResponse], options *runtime.PollUntilDoneOptions) (armnetwork.SubnetsClientCreateOrUpdateResponse, error)
func (*AzureGoClient) PollUntilDoneCreateVM ¶
func (*AzureGoClient) PollUntilDoneCreateVM(ctx context.Context, poll *runtime.Poller[armcompute.VirtualMachinesClientCreateOrUpdateResponse], options *runtime.PollUntilDoneOptions) (armcompute.VirtualMachinesClientCreateOrUpdateResponse, error)
PollUntilDoneCreateVM implements AzureGo.
func (*AzureGoClient) PollUntilDoneCreateVirtNet ¶
func (obj *AzureGoClient) PollUntilDoneCreateVirtNet(ctx context.Context, poll *runtime.Poller[armnetwork.VirtualNetworksClientCreateOrUpdateResponse], options *runtime.PollUntilDoneOptions) (armnetwork.VirtualNetworksClientCreateOrUpdateResponse, error)
func (*AzureGoClient) PollUntilDoneDelAKS ¶
func (obj *AzureGoClient) PollUntilDoneDelAKS(ctx context.Context, poll *runtime.Poller[armcontainerservice.ManagedClustersClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armcontainerservice.ManagedClustersClientDeleteResponse, error)
func (*AzureGoClient) PollUntilDoneDelDisk ¶
func (*AzureGoClient) PollUntilDoneDelDisk(ctx context.Context, poll *runtime.Poller[armcompute.DisksClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armcompute.DisksClientDeleteResponse, error)
PollUntilDoneDelDisk implements AzureGo.
func (*AzureGoClient) PollUntilDoneDelNSG ¶
func (obj *AzureGoClient) PollUntilDoneDelNSG(ctx context.Context, poll *runtime.Poller[armnetwork.SecurityGroupsClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armnetwork.SecurityGroupsClientDeleteResponse, error)
func (*AzureGoClient) PollUntilDoneDelNetInterface ¶
func (*AzureGoClient) PollUntilDoneDelNetInterface(ctx context.Context, poll *runtime.Poller[armnetwork.InterfacesClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armnetwork.InterfacesClientDeleteResponse, error)
PollUntilDoneDelNetInterface implements AzureGo.
func (*AzureGoClient) PollUntilDoneDelPubIP ¶
func (*AzureGoClient) PollUntilDoneDelPubIP(ctx context.Context, poll *runtime.Poller[armnetwork.PublicIPAddressesClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armnetwork.PublicIPAddressesClientDeleteResponse, error)
PollUntilDoneDelPubIP implements AzureGo.
func (*AzureGoClient) PollUntilDoneDelResourceGrp ¶
func (obj *AzureGoClient) PollUntilDoneDelResourceGrp(ctx context.Context, poll *runtime.Poller[armresources.ResourceGroupsClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armresources.ResourceGroupsClientDeleteResponse, error)
func (*AzureGoClient) PollUntilDoneDelSubNet ¶
func (obj *AzureGoClient) PollUntilDoneDelSubNet(ctx context.Context, poll *runtime.Poller[armnetwork.SubnetsClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armnetwork.SubnetsClientDeleteResponse, error)
func (*AzureGoClient) PollUntilDoneDelVM ¶
func (*AzureGoClient) PollUntilDoneDelVM(ctx context.Context, poll *runtime.Poller[armcompute.VirtualMachinesClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armcompute.VirtualMachinesClientDeleteResponse, error)
PollUntilDoneDelVM implements AzureGo.
func (*AzureGoClient) PollUntilDoneDelVirtNet ¶
func (obj *AzureGoClient) PollUntilDoneDelVirtNet(ctx context.Context, poll *runtime.Poller[armnetwork.VirtualNetworksClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armnetwork.VirtualNetworksClientDeleteResponse, error)
func (*AzureGoClient) PublicIPClient ¶
func (azclient *AzureGoClient) PublicIPClient() (*armnetwork.PublicIPAddressesClient, error)
func (*AzureGoClient) SetRegion ¶
func (azclient *AzureGoClient) SetRegion(reg string)
func (*AzureGoClient) SetResourceGrp ¶
func (azclient *AzureGoClient) SetResourceGrp(grp string)
type AzureGoMockClient ¶
type AzureGoMockClient struct {
SubscriptionID string
AzureTokenCred azcore.TokenCredential
Region string
ResourceGrp string
}
func (*AzureGoMockClient) BeginCreateAKS ¶
func (mock *AzureGoMockClient) BeginCreateAKS(resourceName string, parameters armcontainerservice.ManagedCluster, options *armcontainerservice.ManagedClustersClientBeginCreateOrUpdateOptions) (*runtime.Poller[armcontainerservice.ManagedClustersClientCreateOrUpdateResponse], error)
func (*AzureGoMockClient) BeginCreateNIC ¶
func (mock *AzureGoMockClient) BeginCreateNIC(networkInterfaceName string, parameters armnetwork.Interface, options *armnetwork.InterfacesClientBeginCreateOrUpdateOptions) (*runtime.Poller[armnetwork.InterfacesClientCreateOrUpdateResponse], error)
func (*AzureGoMockClient) BeginCreatePubIP ¶
func (mock *AzureGoMockClient) BeginCreatePubIP(publicIPAddressName string, parameters armnetwork.PublicIPAddress, options *armnetwork.PublicIPAddressesClientBeginCreateOrUpdateOptions) (*runtime.Poller[armnetwork.PublicIPAddressesClientCreateOrUpdateResponse], error)
func (*AzureGoMockClient) BeginCreateSecurityGrp ¶
func (mock *AzureGoMockClient) BeginCreateSecurityGrp(networkSecurityGroupName string, parameters armnetwork.SecurityGroup, options *armnetwork.SecurityGroupsClientBeginCreateOrUpdateOptions) (*runtime.Poller[armnetwork.SecurityGroupsClientCreateOrUpdateResponse], error)
func (*AzureGoMockClient) BeginCreateSubNet ¶
func (mock *AzureGoMockClient) BeginCreateSubNet(virtualNetworkName string, subnetName string, subnetParameters armnetwork.Subnet, options *armnetwork.SubnetsClientBeginCreateOrUpdateOptions) (*runtime.Poller[armnetwork.SubnetsClientCreateOrUpdateResponse], error)
func (*AzureGoMockClient) BeginCreateVM ¶
func (mock *AzureGoMockClient) BeginCreateVM(vmName string, parameters armcompute.VirtualMachine, options *armcompute.VirtualMachinesClientBeginCreateOrUpdateOptions) (*runtime.Poller[armcompute.VirtualMachinesClientCreateOrUpdateResponse], error)
func (*AzureGoMockClient) BeginCreateVirtNet ¶
func (mock *AzureGoMockClient) BeginCreateVirtNet(virtualNetworkName string, parameters armnetwork.VirtualNetwork, options *armnetwork.VirtualNetworksClientBeginCreateOrUpdateOptions) (*runtime.Poller[armnetwork.VirtualNetworksClientCreateOrUpdateResponse], error)
func (*AzureGoMockClient) BeginDeleteAKS ¶
func (mock *AzureGoMockClient) BeginDeleteAKS(resourceName string, options *armcontainerservice.ManagedClustersClientBeginDeleteOptions) (*runtime.Poller[armcontainerservice.ManagedClustersClientDeleteResponse], error)
func (*AzureGoMockClient) BeginDeleteDisk ¶
func (mock *AzureGoMockClient) BeginDeleteDisk(diskName string, options *armcompute.DisksClientBeginDeleteOptions) (*runtime.Poller[armcompute.DisksClientDeleteResponse], error)
func (*AzureGoMockClient) BeginDeleteNIC ¶
func (mock *AzureGoMockClient) BeginDeleteNIC(networkInterfaceName string, options *armnetwork.InterfacesClientBeginDeleteOptions) (*runtime.Poller[armnetwork.InterfacesClientDeleteResponse], error)
func (*AzureGoMockClient) BeginDeletePubIP ¶
func (mock *AzureGoMockClient) BeginDeletePubIP(publicIPAddressName string, options *armnetwork.PublicIPAddressesClientBeginDeleteOptions) (*runtime.Poller[armnetwork.PublicIPAddressesClientDeleteResponse], error)
func (*AzureGoMockClient) BeginDeleteResourceGrp ¶
func (mock *AzureGoMockClient) BeginDeleteResourceGrp(options *armresources.ResourceGroupsClientBeginDeleteOptions) (*runtime.Poller[armresources.ResourceGroupsClientDeleteResponse], error)
func (*AzureGoMockClient) BeginDeleteSecurityGrp ¶
func (mock *AzureGoMockClient) BeginDeleteSecurityGrp(networkSecurityGroupName string, options *armnetwork.SecurityGroupsClientBeginDeleteOptions) (*runtime.Poller[armnetwork.SecurityGroupsClientDeleteResponse], error)
func (*AzureGoMockClient) BeginDeleteSubNet ¶
func (mock *AzureGoMockClient) BeginDeleteSubNet(virtualNetworkName string, subnetName string, options *armnetwork.SubnetsClientBeginDeleteOptions) (*runtime.Poller[armnetwork.SubnetsClientDeleteResponse], error)
func (*AzureGoMockClient) BeginDeleteVM ¶
func (mock *AzureGoMockClient) BeginDeleteVM(vmName string, options *armcompute.VirtualMachinesClientBeginDeleteOptions) (*runtime.Poller[armcompute.VirtualMachinesClientDeleteResponse], error)
func (*AzureGoMockClient) BeginDeleteVirtNet ¶
func (mock *AzureGoMockClient) BeginDeleteVirtNet(virtualNetworkName string, options *armnetwork.VirtualNetworksClientBeginDeleteOptions) (*runtime.Poller[armnetwork.VirtualNetworksClientDeleteResponse], error)
func (*AzureGoMockClient) CreateResourceGrp ¶
func (mock *AzureGoMockClient) CreateResourceGrp(parameters armresources.ResourceGroup, options *armresources.ResourceGroupsClientCreateOrUpdateOptions) (armresources.ResourceGroupsClientCreateOrUpdateResponse, error)
func (*AzureGoMockClient) CreateSSHKey ¶
func (mock *AzureGoMockClient) CreateSSHKey(sshPublicKeyName string, parameters armcompute.SSHPublicKeyResource, options *armcompute.SSHPublicKeysClientCreateOptions) (armcompute.SSHPublicKeysClientCreateResponse, error)
func (*AzureGoMockClient) DeleteSSHKey ¶
func (mock *AzureGoMockClient) DeleteSSHKey(sshPublicKeyName string, options *armcompute.SSHPublicKeysClientDeleteOptions) (armcompute.SSHPublicKeysClientDeleteResponse, error)
func (*AzureGoMockClient) InitClient ¶
func (mock *AzureGoMockClient) InitClient(storage resources.StorageFactory) error
func (*AzureGoMockClient) ListClusterAdminCredentials ¶
func (mock *AzureGoMockClient) ListClusterAdminCredentials(resourceName string, options *armcontainerservice.ManagedClustersClientListClusterAdminCredentialsOptions) (armcontainerservice.ManagedClustersClientListClusterAdminCredentialsResponse, error)
func (*AzureGoMockClient) ListKubernetesVersions ¶
func (mock *AzureGoMockClient) ListKubernetesVersions() (armcontainerservicev4.ManagedClustersClientListKubernetesVersionsResponse, error)
func (*AzureGoMockClient) ListLocations ¶
func (mock *AzureGoMockClient) ListLocations() ([]string, error)
ListLocations: TODO: unable to mock the Pager so moved on with more work for ListLocation method instead of it returning (*runtime.Pager[armsubscriptions.ClientListLocationsResponse], error) it will return the ([]string, error)
func (*AzureGoMockClient) ListVMTypes ¶
func (mock *AzureGoMockClient) ListVMTypes() ([]string, error)
func (*AzureGoMockClient) PollUntilDoneCreateAKS ¶
func (mock *AzureGoMockClient) PollUntilDoneCreateAKS(ctx context.Context, poll *runtime.Poller[armcontainerservice.ManagedClustersClientCreateOrUpdateResponse], options *runtime.PollUntilDoneOptions) (armcontainerservice.ManagedClustersClientCreateOrUpdateResponse, error)
func (*AzureGoMockClient) PollUntilDoneCreateNSG ¶
func (mock *AzureGoMockClient) PollUntilDoneCreateNSG(ctx context.Context, poll *runtime.Poller[armnetwork.SecurityGroupsClientCreateOrUpdateResponse], options *runtime.PollUntilDoneOptions) (armnetwork.SecurityGroupsClientCreateOrUpdateResponse, error)
func (*AzureGoMockClient) PollUntilDoneCreateNetInterface ¶
func (mock *AzureGoMockClient) PollUntilDoneCreateNetInterface(ctx context.Context, poll *runtime.Poller[armnetwork.InterfacesClientCreateOrUpdateResponse], options *runtime.PollUntilDoneOptions) (armnetwork.InterfacesClientCreateOrUpdateResponse, error)
func (*AzureGoMockClient) PollUntilDoneCreatePubIP ¶
func (mock *AzureGoMockClient) PollUntilDoneCreatePubIP(ctx context.Context, poll *runtime.Poller[armnetwork.PublicIPAddressesClientCreateOrUpdateResponse], options *runtime.PollUntilDoneOptions) (armnetwork.PublicIPAddressesClientCreateOrUpdateResponse, error)
func (*AzureGoMockClient) PollUntilDoneCreateSubNet ¶
func (mock *AzureGoMockClient) PollUntilDoneCreateSubNet(ctx context.Context, poll *runtime.Poller[armnetwork.SubnetsClientCreateOrUpdateResponse], options *runtime.PollUntilDoneOptions) (armnetwork.SubnetsClientCreateOrUpdateResponse, error)
func (*AzureGoMockClient) PollUntilDoneCreateVM ¶
func (mock *AzureGoMockClient) PollUntilDoneCreateVM(ctx context.Context, poll *runtime.Poller[armcompute.VirtualMachinesClientCreateOrUpdateResponse], options *runtime.PollUntilDoneOptions) (armcompute.VirtualMachinesClientCreateOrUpdateResponse, error)
func (*AzureGoMockClient) PollUntilDoneCreateVirtNet ¶
func (mock *AzureGoMockClient) PollUntilDoneCreateVirtNet(ctx context.Context, poll *runtime.Poller[armnetwork.VirtualNetworksClientCreateOrUpdateResponse], options *runtime.PollUntilDoneOptions) (armnetwork.VirtualNetworksClientCreateOrUpdateResponse, error)
func (*AzureGoMockClient) PollUntilDoneDelAKS ¶
func (mock *AzureGoMockClient) PollUntilDoneDelAKS(ctx context.Context, poll *runtime.Poller[armcontainerservice.ManagedClustersClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armcontainerservice.ManagedClustersClientDeleteResponse, error)
func (*AzureGoMockClient) PollUntilDoneDelDisk ¶
func (mock *AzureGoMockClient) PollUntilDoneDelDisk(ctx context.Context, poll *runtime.Poller[armcompute.DisksClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armcompute.DisksClientDeleteResponse, error)
func (*AzureGoMockClient) PollUntilDoneDelNSG ¶
func (mock *AzureGoMockClient) PollUntilDoneDelNSG(ctx context.Context, poll *runtime.Poller[armnetwork.SecurityGroupsClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armnetwork.SecurityGroupsClientDeleteResponse, error)
func (*AzureGoMockClient) PollUntilDoneDelNetInterface ¶
func (mock *AzureGoMockClient) PollUntilDoneDelNetInterface(ctx context.Context, poll *runtime.Poller[armnetwork.InterfacesClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armnetwork.InterfacesClientDeleteResponse, error)
func (*AzureGoMockClient) PollUntilDoneDelPubIP ¶
func (mock *AzureGoMockClient) PollUntilDoneDelPubIP(ctx context.Context, poll *runtime.Poller[armnetwork.PublicIPAddressesClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armnetwork.PublicIPAddressesClientDeleteResponse, error)
func (*AzureGoMockClient) PollUntilDoneDelResourceGrp ¶
func (mock *AzureGoMockClient) PollUntilDoneDelResourceGrp(ctx context.Context, poll *runtime.Poller[armresources.ResourceGroupsClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armresources.ResourceGroupsClientDeleteResponse, error)
func (*AzureGoMockClient) PollUntilDoneDelSubNet ¶
func (mock *AzureGoMockClient) PollUntilDoneDelSubNet(ctx context.Context, poll *runtime.Poller[armnetwork.SubnetsClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armnetwork.SubnetsClientDeleteResponse, error)
func (*AzureGoMockClient) PollUntilDoneDelVM ¶
func (mock *AzureGoMockClient) PollUntilDoneDelVM(ctx context.Context, poll *runtime.Poller[armcompute.VirtualMachinesClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armcompute.VirtualMachinesClientDeleteResponse, error)
func (*AzureGoMockClient) PollUntilDoneDelVirtNet ¶
func (mock *AzureGoMockClient) PollUntilDoneDelVirtNet(ctx context.Context, poll *runtime.Poller[armnetwork.VirtualNetworksClientDeleteResponse], options *runtime.PollUntilDoneOptions) (armnetwork.VirtualNetworksClientDeleteResponse, error)
func (*AzureGoMockClient) SetRegion ¶
func (mock *AzureGoMockClient) SetRegion(s string)
func (*AzureGoMockClient) SetResourceGrp ¶
func (mock *AzureGoMockClient) SetResourceGrp(s string)
type AzureProvider ¶
type AzureProvider struct {
ClusterName string `json:"cluster_name"`
HACluster bool `json:"ha_cluster"`
ResourceGroup string `json:"resource_group"`
Region string `json:"region"`
SSHPath string `json:"ssh_key"`
Metadata Metadata
Client AzureGo
}
func ReturnAzureStruct ¶
func ReturnAzureStruct(metadata resources.Metadata, ClientOption func() AzureGo) (*AzureProvider, error)
func (*AzureProvider) Application ¶
func (cloud *AzureProvider) Application(s string) resources.CloudFactory
func (*AzureProvider) CNI ¶
func (cloud *AzureProvider) CNI(s string) resources.CloudFactory
func (*AzureProvider) CreateNetworkInterface ¶
func (*AzureProvider) CreatePublicIP ¶
func (obj *AzureProvider) CreatePublicIP(ctx context.Context, storage resources.StorageFactory, publicIPName string, index int) error
func (*AzureProvider) CreateSubnet ¶
func (obj *AzureProvider) CreateSubnet(ctx context.Context, storage resources.StorageFactory, subnetName string) error
func (*AzureProvider) CreateUploadSSHKeyPair ¶
func (obj *AzureProvider) CreateUploadSSHKeyPair(storage resources.StorageFactory) error
CreateUploadSSHKeyPair implements resources.CloudFactory.
func (*AzureProvider) CreateVirtualNetwork ¶
func (obj *AzureProvider) CreateVirtualNetwork(ctx context.Context, storage resources.StorageFactory, resName string) error
func (*AzureProvider) DelFirewall ¶
func (obj *AzureProvider) DelFirewall(storage resources.StorageFactory) error
DelFirewall implements resources.CloudFactory.
func (*AzureProvider) DelManagedCluster ¶
func (obj *AzureProvider) DelManagedCluster(storage resources.StorageFactory) error
DelManagedCluster implements resources.CloudFactory.
func (*AzureProvider) DelNetwork ¶
func (obj *AzureProvider) DelNetwork(storage resources.StorageFactory) error
DelNetwork implements resources.CloudFactory.
func (*AzureProvider) DelSSHKeyPair ¶
func (obj *AzureProvider) DelSSHKeyPair(storage resources.StorageFactory) error
DelSSHKeyPair implements resources.CloudFactory.
func (*AzureProvider) DelVM ¶
func (obj *AzureProvider) DelVM(storage resources.StorageFactory, indexNo int) error
DelVM implements resources.CloudFactory.
func (*AzureProvider) DeleteDisk ¶
func (obj *AzureProvider) DeleteDisk(ctx context.Context, storage resources.StorageFactory, index int) error
func (*AzureProvider) DeleteNetworkInterface ¶
func (obj *AzureProvider) DeleteNetworkInterface(ctx context.Context, storage resources.StorageFactory, index int) error
func (*AzureProvider) DeletePublicIP ¶
func (obj *AzureProvider) DeletePublicIP(ctx context.Context, storage resources.StorageFactory, index int) error
func (*AzureProvider) DeleteSubnet ¶
func (obj *AzureProvider) DeleteSubnet(ctx context.Context, storage resources.StorageFactory) error
func (*AzureProvider) DeleteVirtualNetwork ¶
func (obj *AzureProvider) DeleteVirtualNetwork(ctx context.Context, storage resources.StorageFactory) error
func (*AzureProvider) GetHostNameAllWorkerNode ¶
func (*AzureProvider) GetHostNameAllWorkerNode() []string
func (*AzureProvider) GetManagedKubernetes ¶
func (*AzureProvider) GetManagedKubernetes(resources.StorageFactory)
GetManagedKubernetes implements resources.CloudFactory.
func (*AzureProvider) GetStateForHACluster ¶
func (*AzureProvider) GetStateForHACluster(storage resources.StorageFactory) (cloud_control_res.CloudResourceState, error)
GetStateForHACluster implements resources.CloudFactory. WARN: the array copy is a shallow copy
func (*AzureProvider) InitState ¶
func (obj *AzureProvider) InitState(storage resources.StorageFactory, operation string) error
InitState implements resources.CloudFactory.
func (*AzureProvider) Name ¶
func (cloud *AzureProvider) Name(resName string) resources.CloudFactory
Name it will contain the name of the resource to be created
func (*AzureProvider) NewFirewall ¶
func (obj *AzureProvider) NewFirewall(storage resources.StorageFactory) error
NewFirewall implements resources.CloudFactory.
func (*AzureProvider) NewManagedCluster ¶
func (obj *AzureProvider) NewManagedCluster(storage resources.StorageFactory, noOfNodes int) error
NewManagedCluster implements resources.CloudFactory.
func (*AzureProvider) NewNetwork ¶
func (obj *AzureProvider) NewNetwork(storage resources.StorageFactory) error
NewNetwork implements resources.CloudFactory.
func (*AzureProvider) NewVM ¶
func (obj *AzureProvider) NewVM(storage resources.StorageFactory, indexNo int) error
NewVM implements resources.CloudFactory.
func (*AzureProvider) NoOfControlPlane ¶
func (obj *AzureProvider) NoOfControlPlane(no int, setter bool) (int, error)
NoOfControlPlane implements resources.CloudFactory.
func (*AzureProvider) NoOfDataStore ¶
func (obj *AzureProvider) NoOfDataStore(no int, setter bool) (int, error)
NoOfDataStore implements resources.CloudFactory.
func (*AzureProvider) NoOfWorkerPlane ¶
func (obj *AzureProvider) NoOfWorkerPlane(storage resources.StorageFactory, no int, setter bool) (int, error)
NoOfWorkerPlane implements resources.CloudFactory.
func (*AzureProvider) Role ¶
func (cloud *AzureProvider) Role(resRole string) resources.CloudFactory
Role it will contain whether the resource to be created belongs for controlplane component or loadbalancer...
func (*AzureProvider) SupportForApplications ¶
func (cloud *AzureProvider) SupportForApplications() bool
SupportForApplications if its ha its always false instead it tells whether the provider has support in their managed offerering
func (*AzureProvider) SupportForCNI ¶
func (cloud *AzureProvider) SupportForCNI() bool
func (*AzureProvider) SwitchCluster ¶
func (obj *AzureProvider) SwitchCluster(storage resources.StorageFactory) error
func (*AzureProvider) VMType ¶
func (cloud *AzureProvider) VMType(size string) resources.CloudFactory
VMType it will contain which vmType to create
func (*AzureProvider) Version ¶
func (obj *AzureProvider) Version(ver string) resources.CloudFactory
Version implements resources.CloudFactory.
func (*AzureProvider) Visibility ¶
func (cloud *AzureProvider) Visibility(toBePublic bool) resources.CloudFactory
Visibility whether to have the resource as public or private (i.e. VMs)
type AzureStateVM ¶
type AzureStateVM struct {
Name string `json:"name"`
NetworkSecurityGroupName string `json:"network_security_group_name"`
NetworkSecurityGroupID string `json:"network_security_group_id"`
DiskName string `json:"disk_name"`
PublicIPName string `json:"public_ip_name"`
PublicIPID string `json:"public_ip_id"`
NetworkInterfaceName string `json:"network_interface_name"`
NetworkInterfaceID string `json:"network_interface_id"`
PrivateIP string `json:"private_ip"`
PublicIP string `json:"public_ip"`
HostName string `json:"hostname"`
}
type AzureStateVMs ¶
type AzureStateVMs struct {
Names []string `json:"names"`
NetworkSecurityGroupName string `json:"network_security_group_name"`
NetworkSecurityGroupID string `json:"network_security_group_id"`
DiskNames []string `json:"disk_names"`
PublicIPNames []string `json:"public_ip_names"`
PublicIPIDs []string `json:"public_ip_ids"`
PrivateIPs []string `json:"private_ips"`
PublicIPs []string `json:"public_ips"`
NetworkInterfaceNames []string `json:"network_interface_names"`
NetworkInterfaceIDs []string `json:"network_interface_ids"`
Hostnames []string `json:"hostnames"`
}
type Credential ¶
type StateConfiguration ¶
type StateConfiguration struct {
IsCompleted bool `json:"status"`
ClusterName string `json:"cluster_name"`
Region string `json:"region"`
ResourceGroupName string `json:"resource_group_name"`
// SSHID string `json:"ssh_id"`
SSHUser string `json:"ssh_usr"`
SSHPrivateKeyLoc string `json:"ssh_private_key_location"`
SSHKeyName string `json:"sshkey_name"`
// ManagedCluster
ManagedClusterName string `json:"managed_cluster_name"`
NoManagedNodes int `json:"no_managed_cluster_nodes"`
SubnetName string `json:"subnet_name"`
SubnetID string `json:"subnet_id"`
VirtualNetworkName string `json:"virtual_network_name"`
VirtualNetworkID string `json:"virtual_network_id"`
InfoControlPlanes AzureStateVMs `json:"info_control_planes"`
InfoWorkerPlanes AzureStateVMs `json:"info_worker_planes"`
InfoDatabase AzureStateVMs `json:"info_database"`
InfoLoadBalancer AzureStateVM `json:"info_load_balancer"`
KubernetesDistro string `json:"k8s_distro"`
KubernetesVer string `json:"k8s_version"`
}