Documentation
¶
Index ¶
- Constants
- func ClusterInfoInjecter(clusterName, reg, size string, noOfNodes int, application, cniPlugin string) payload.CivoProvider
- func CreateCluster(cargo payload.CivoProvider) error
- func Credentials() bool
- func DeleteCluster(region, name string) error
- func GetPath(flag int8, params ...string) string
- func SwitchContext(clusterName, region string) error
Constants ¶
const ( RegionLON = "LON1" RegionFRA = "FRA1" RegionNYC = "NYC1" )
Variables ¶
This section is empty.
Functions ¶
func ClusterInfoInjecter ¶
func ClusterInfoInjecter(clusterName, reg, size string, noOfNodes int, application, cniPlugin string) payload.CivoProvider
ClusterInfoInjecter Serializes the information which is return as payload.CivoProvider for sending it to API {clustername, regionCode, Size of Nodes, No of nodes, Applications(optional), cniPlugion(optional)}
func CreateCluster ¶
func CreateCluster(cargo payload.CivoProvider) error
CreateCluster creates cluster as provided configuration and returns whether it fails or not
func Credentials ¶
func Credentials() bool
func DeleteCluster ¶
DeleteCluster deletes cluster from the given name and region
func GetPath ¶
GetPath use this in every function and differentiate the logic by using if-else flag is used to indicate 1 -> KUBECONFIG, 0 -> CREDENTIALS
func SwitchContext ¶
SwitchContext TODO: Add description
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.